@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2018-2019 Fetch.AI Limited
+#   Copyright 2018-2022 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,10 +34,13 @@ from aea.__version__ import (
     __url__,
     __version__,
 )
+from aea.crypto.plugin import load_all_plugins
 
 
 AEA_DIR = os.path.dirname(inspect.getfile(inspect.currentframe()))  # type: ignore
 
+load_all_plugins()
+
 
 def get_current_aea_version() -> Version:
     """Get current version."""
