@@ -44,14 +44,18 @@ DEFAULT_SETTLE_TIMEOUT = 60
 @click.argument(
     "type_",
     metavar="TYPE",
-    type=click.Choice(ledger_apis_registry.supported_ids),
+    type=click.Choice(list(ledger_apis_registry.supported_ids)),
     required=True,
 )
 @click.argument(
-    "address", type=str, required=True,
+    "address",
+    type=str,
+    required=True,
 )
 @click.argument(
-    "amount", type=int, required=True,
+    "amount",
+    type=int,
+    required=True,
 )
 @click.argument("fee", type=int, required=False, default=100)
 @password_option()
