@@ -49,7 +49,8 @@ def replace_component_ids(
 
 @replace_component_ids.register(AgentConfig)  # type: ignore
 def _(
-    arg: AgentConfig, replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
+    arg: AgentConfig,
+    replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
 ) -> None:
     """
     Replace references in agent configuration.
@@ -105,20 +106,22 @@ def _(
                 component_id.component_type,
                 replacements_by_type[component_id.public_id],
             )
-            old_value = arg.component_configurations.pop(component_id)
-            arg.component_configurations[new_component_id] = old_value
+            old_config = arg.component_configurations.pop(component_id)
+            arg.component_configurations[new_component_id] = old_config
 
 
 @replace_component_ids.register(ProtocolConfig)  # type: ignore
 def _(
-    _arg: ProtocolConfig, _replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
+    _arg: ProtocolConfig,
+    _replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
 ) -> None:
     """Do nothing - protocols have no references."""
 
 
 @replace_component_ids.register(ConnectionConfig)  # type: ignore
 def _(
-    arg: ConnectionConfig, replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
+    arg: ConnectionConfig,
+    replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
 ) -> None:
     """Replace references in a connection configuration."""
     _replace_component_id(
@@ -139,14 +142,16 @@ def _(
 
 @replace_component_ids.register(ContractConfig)  # type: ignore
 def _(  # type: ignore
-    _arg: ContractConfig, _replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
+    _arg: ContractConfig,
+    _replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
 ) -> None:
     """Do nothing - contracts have no references."""
 
 
 @replace_component_ids.register(SkillConfig)  # type: ignore
 def _(
-    arg: SkillConfig, replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
+    arg: SkillConfig,
+    replacements: Dict[ComponentType, Dict[PublicId, PublicId]],
 ) -> None:
     """Replace references in a skill configuration."""
     _replace_component_id(
@@ -174,7 +179,9 @@ def _replace_component_id(
     :param replacements: the replacements.
     """
     for component_type in types_to_update:
-        public_id_set = getattr(config, component_type.to_plural(), set())
+        public_id_set: Set[PublicId] = getattr(
+            config, component_type.to_plural(), set()
+        )
         replacements_given_type = replacements.get(component_type, {})
         for old_public_id in list(public_id_set):
             new_public_id = replacements_given_type.get(old_public_id, old_public_id)
