@@ -97,7 +97,10 @@ class DecisionMakerHandler(BaseDecisionMakerHandler):
         """
         kwargs: Dict[str, Any] = {}
         super().__init__(
-            identity=identity, wallet=wallet, config=config, **kwargs,
+            identity=identity,
+            wallet=wallet,
+            config=config,
+            **kwargs,
         )
         self.signing_dialogues = DecisionMakerHandler.SigningDialogues(
             self.self_address
@@ -176,7 +179,9 @@ class DecisionMakerHandler(BaseDecisionMakerHandler):
                 signing_msg.raw_message.is_deprecated_mode,
             )
         signing_msg_response = signing_dialogue.reply(
-            performative=performative, target_message=signing_msg, **kwargs,
+            performative=performative,
+            target_message=signing_msg,
+            **kwargs,
         )
         self.message_out_queue.put(signing_msg_response)
 
@@ -203,6 +208,8 @@ class DecisionMakerHandler(BaseDecisionMakerHandler):
                 signing_msg.raw_transaction.ledger_id, signed_tx
             )
         signing_msg_response = signing_dialogue.reply(
-            performative=performative, target_message=signing_msg, **kwargs,
+            performative=performative,
+            target_message=signing_msg,
+            **kwargs,
         )
         self.message_out_queue.put(signing_msg_response)
