@@ -110,10 +110,11 @@ class Profiling(Runnable):
             def make_fn(obj: Any) -> Callable:
                 orig_new = obj.__new__
                 # pylint: disable=protected-access  # type: ignore
+                obj_copy = obj
 
                 @wraps(orig_new)
                 def new(*args: Any, **kwargs: Any) -> Callable:
-                    self._counter[obj] += 1
+                    self._counter[obj_copy] += 1
                     if orig_new is object.__new__:
                         return orig_new(args[0])  # pragma: nocover
                     return orig_new(*args, **kwargs)  # pragma: nocover
@@ -179,8 +180,7 @@ class Profiling(Runnable):
         """Return dict with counted object instances present now."""
         result: Dict = Counter()
 
-        lock.acquire()
-        try:
+        with lock:
             for obj_type in self._objects_instances_to_count:
                 result[obj_type.__name__] += 0
 
@@ -188,8 +188,6 @@ class Profiling(Runnable):
                 for obj_type in self._objects_instances_to_count:
                     if isinstance(obj, obj_type):
                         result[obj_type.__name__] += 1
-        finally:
-            lock.release()
         return result
 
     def get_objecst_created(self) -> Dict:
