@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2018-2019 Fetch.AI Limited
+#   Copyright 2018-2022 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ class GenericDataModel(DataModel):  # pylint: disable=too-few-public-methods
         self, data_model_name: str, data_model_attributes: Dict[str, Any]
     ) -> None:
         """Initialise the dataModel."""
-        self.attributes = []  # type: List[Attribute]
+        attributes = []  # type: List[Attribute]
         for values in data_model_attributes.values():
             enforce(
                 values["type"] in SUPPORTED_TYPES.keys(),
@@ -46,7 +46,7 @@ class GenericDataModel(DataModel):  # pylint: disable=too-few-public-methods
                 isinstance(values["is_required"], bool),
                 "Wrong type for is_required. Must be bool!",
             )
-            self.attributes.append(
+            attributes.append(
                 Attribute(
                     name=values["name"],  # type: ignore
                     type_=SUPPORTED_TYPES[values["type"]],
@@ -54,7 +54,7 @@ class GenericDataModel(DataModel):  # pylint: disable=too-few-public-methods
                 )
             )
 
-        super().__init__(data_model_name, self.attributes)
+        super().__init__(data_model_name, attributes)
 
 
 AGENT_LOCATION_MODEL = DataModel(
