@@ -572,20 +572,20 @@ class Terms:
         enforce(
             isinstance(self._amount_by_currency_id, dict)
             and all(
-                [
+                (
                     isinstance(key, str) and isinstance(value, int)
                     for key, value in self._amount_by_currency_id.items()
-                ]
+                )
             ),
             "amount_by_currency_id must be a dictionary with str keys and int values.",
         )
         enforce(
             isinstance(self._quantities_by_good_id, dict)
             and all(
-                [
+                (
                     isinstance(key, str) and isinstance(value, int)
                     for key, value in self._quantities_by_good_id.items()
-                ]
+                )
             ),
             "quantities_by_good_id must be a dictionary with str keys and int values.",
         )
@@ -599,35 +599,35 @@ class Terms:
             or (
                 isinstance(self._fee_by_currency_id, dict)
                 and all(
-                    [
+                    (
                         isinstance(key, str) and isinstance(value, int) and value >= 0
                         for key, value in self._fee_by_currency_id.items()
-                    ]
+                    )
                 )
             ),
             "fee must be None or Dict[str, int] with positive fees only.",
         )
         enforce(
             all(
-                [
+                (
                     key in self._amount_by_currency_id
                     for key in self._fee_by_currency_id.keys()
-                ]
+                )
             ),
             "Fee dictionary has keys which are not present in amount dictionary.",
         )
         if self._is_strict:
             is_pos_amounts = all(
-                [amount >= 0 for amount in self._amount_by_currency_id.values()]
+                (amount >= 0 for amount in self._amount_by_currency_id.values())
             )
             is_neg_amounts = all(
-                [amount <= 0 for amount in self._amount_by_currency_id.values()]
+                (amount <= 0 for amount in self._amount_by_currency_id.values())
             )
             is_pos_quantities = all(
-                [quantity >= 0 for quantity in self._quantities_by_good_id.values()]
+                (quantity >= 0 for quantity in self._quantities_by_good_id.values())
             )
             is_neg_quantities = all(
-                [quantity <= 0 for quantity in self._quantities_by_good_id.values()]
+                (quantity <= 0 for quantity in self._quantities_by_good_id.values())
             )
             enforce(
                 (is_pos_amounts and is_neg_quantities)
